#
# spec file for package python-arviz
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname arviz
Name:           python-arviz
Version:        0.16.1
Release:        1.1
Summary:        Exploratory analysis of Bayesian models
License:        Apache-2.0
URL:            http://github.com/arviz-devs/arviz
Source:         https://github.com/arviz-devs/arviz/archive/v%{version}.tar.gz#/%{modname}-%{version}.tar.gz
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module cloudpickle}
BuildRequires:  %{python_module bokeh}
BuildRequires:  %{python_module dash}
BuildRequires:  %{python_module dask-array}
BuildRequires:  %{python_module dask}
BuildRequires:  %{python_module h5netcdf}
BuildRequires:  %{python_module matplotlib >= 3.5}
BuildRequires:  %{python_module numba}
BuildRequires:  %{python_module numpy >= 1.20.0}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pandas >= 1.4.0}
BuildRequires:  %{python_module pytest >= 0.23}
BuildRequires:  %{python_module scipy >= 1.8.0}
BuildRequires:  %{python_module setuptools >= 60.0.0}
BuildRequires:  %{python_module typing_extensions}
BuildRequires:  %{python_module ujson}
BuildRequires:  %{python_module xarray >= 0.21.0}
BuildRequires:  %{python_module xarray-einstats >= 0.3}
BuildRequires:  %{python_module zarr}
# /SECTION
BuildRequires:  fdupes
Requires:       python-h5netcdf
Requires:       python-matplotlib >= 3.2
Requires:       python-numpy >= 1.20.0
Requires:       python-packaging
Requires:       python-pandas >= 1.4.0
Requires:       python-scipy >= 1.8.0
Requires:       python-setuptools >= 60.0.0
Requires:       python-typing_extensions
Requires:       python-xarray >= 0.21.0
Requires:       python-xarray-einstats
Recommends:     python-bokeh >= 1.4.0
Recommends:     python-numba
Recommends:     python-ujson
BuildArch:      noarch
%python_subpackages

%description
ArviZ is a Python package for exploratory analysis of Bayesian models. Includes
functions for posterior analysis, data storage, model checking, comparison and
diagnostics.

%prep
%setup -q -n %{modname}-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Matplotlib tests try to save results to non-writeable dir
donttest="test_plots_matplotlib"
donttest+=" or test_plot_separation"
%pytest -k "not ($donttest)"

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%{python_sitelib}/%{modname}
%{python_sitelib}/%{modname}-%{version}-py%{python_version}.egg-info/

%changelog
* Wed Jul 26 2023 Dirk Müller <dmueller@suse.com>
- update to 0.16.1:
  * Fix Numba deprecation errors and incorrect nopython usage
  * Rerun Numba notebook
* Sun Jul 16 2023 Dirk Müller <dmueller@suse.com>
- update to 0.16.0:
  * Add InferenceData<->DataTree conversion functions (2253)
  * Bayes Factor plot: Use arviz's kde instead of the one from
    scipy (2237)
  * InferenceData objects can now be appended to existing netCDF4
    files and to specific groups within them (2227)
  * Added facade functions `az.to_zarr` and `az.from_zarr` (2236)
  * Replace deprecated np.product with np.prod (2249)
  * Fix numba deprecation warning (2246)
  * Fixes for creating numpy object array (2233 and 2239)
  * Adapt histograms generated by plot_dist to input dtype (2247)
* Fri Jun  2 2023 Steve Kowalik <steven.kowalik@suse.com>
- No longer skip Python 3.8 and 3.11.
- Add missing BuildRequires on dask-array.
* Wed Mar 22 2023 Daniel Garcia <daniel.garcia@suse.com>
- skip python 3.11 and python 3.8 because some dependencies doesn't
  support that python versions
- Update to 0.15.1
  - Fix memory usage and improve efficiency in `from_emcee`
    ([2215](https://github.com/arviz-devs/arviz/pull/2215))
  - Lower pandas version needed
    ([2217](https://github.com/arviz-devs/arviz/pull/2217))
- 0.15.0
  - Adds Savage-Dickey density ratio plot for Bayes factor
    approximation.
    ([2037](https://github.com/arviz-devs/arviz/pull/2037),
    [2152](https://github.com/arviz-devs/arviz/pull/2152))
  - Add `CmdStanPySamplingWrapper` and `PyMCSamplingWrapper` classes
    ([2158](https://github.com/arviz-devs/arviz/pull/2158))
  - Changed dependency on netcdf4-python to h5netcdf
    ([2122](https://github.com/arviz-devs/arviz/pull/2122))
  - Fix `reloo` outdated usage of `ELPDData`
    ([2158](https://github.com/arviz-devs/arviz/pull/2158))
  - plot_bpv smooth discrete data only when computing u_values
    ([2179](https://github.com/arviz-devs/arviz/pull/2179))
  - Fix bug when beanmachine objects lack some fields
    ([2154](https://github.com/arviz-devs/arviz/pull/2154))
  - Fix gap for `plot_trace` with option `kind="rank_bars"`
    ([2180](https://github.com/arviz-devs/arviz/pull/2180))
  - Fix `plot_lm` unsupported usage of `np.tile`
    ([2186](https://github.com/arviz-devs/arviz/pull/2186))
  - Update `_z_scale` to work with SciPy 1.10
    ([2186](https://github.com/arviz-devs/arviz/pull/2186))
  - Fix bug in BaseLabeller when combining with with NoVarLabeller
    ([2200](https://github.com/arviz-devs/arviz/pull/2200))
* Thu Nov 24 2022 Daniel Garcia <daniel.garcia@suse.com>
- Update to 0.14.0
  * Add weight_predictions function to allow generation of weighted predictions
    from two or more InfereceData with posterior_predictive groups and a set of
    weights (2147)
  * Add Savage-Dickey density ratio plot for Bayes factor approximation. (2037,
    [2152](#2152)
  * Adds rug plot for observed variables to plot_ppc. (2161)
  * Fix dimension ordering for plot_trace with divergences (2151)
- v0.13.0 (2022 Oct 22)
  * Add side argument to plot_violin to allow single-sided violin plots (1996)
  * Added support for Bean Machine via the function from_beanmachine. (2107
  * Add support for warmup samples in from_pystan for PyStan 3. (2132
  * Add exception in az.plot_hdi for x of type np.datetime64 and smooth=True
    (2016)
  * Change ax.plot usage to ax.scatter in plot_pair (1990)
  * Example data has been moved to the arviz_example_data repository and is now
    included using git subtree. (2096 and 2105)
  * Bokeh kde contour plots started to use contourpy package (2104)
  * Update default Bokeh markers for rcparams (2104)
  * Correctly (re)order dimensions for bfmi and plot_energy (2126)
  * Fix bug with the dimension order dependency (2103)
  * Add testing module for labeller classes (2095)
  * Skip compression for object dtype while creating a netcdf file (2129)
  * Fix issue in dim generation when default dims are present in user inputed
    dims (2138)
  * Save InferenceData level attrs to netcdf and zarr (2131)
  * Update tests and docs for updated example data (2137)
  * Copy coords before modifying in ppcplot (2160)
  * Removed fill_last, contour and plot_kwargs arguments from plot_pair
    function (2085)
  * Add translation overview to contributing guide (2041)
  * Improve how to release page (2144)
- v0.12.1 (2022 May 12)
  * Add stat_focus argument to arviz.summary (1998)
  * psislw now smooths log-weights even when shape is lower than 1/3(2011)
  * Fixes from_cmdstanpy, handles parameter vectors of length 1 (2023)
  * Fix typo in BaseLabeller that broke NoVarLabeller (2018)
  * Adding plotting guides (2025)
  * Update links to use new domain (2013)
- v0.12.0 (2022 Mar 23)
  * Add new convenience function arviz.extract_dataset (1725)
  * Add combine_dims argument to several functions (1676)
  * [experimental] Enable dask chunking information to be passed to
    InferenceData.from_netcdf with regex support (1749)
  * Allow kwargs to customize appearance of the mean in plot_lm
  * Add dict option to from_cmdstan log_likelihood parameter (as in
    from_pystan)
  * Unify model comparison API. Both plot_compare, plot_elpd can now take dicts
    of InferenceData or ELPDData (1690)
  * Change default for rcParam stats.ic_pointwise to True (1690)
  * Add new plot type: plot_ecdf (1753)
  * Drop Python 3.6 support (1430)
  * Bokeh 3 compatibility. (1919)
  * Remove manual setting of 2d KDE limits (1939)
  * Pin to bokeh<3 version (1954)
  * Fix legend labels in plot_ppc to reflect prior or posterior. (1967)
  * Change DataFrame.append to pandas.concat (1973)
  * Fix axis sharing behaviour in plot_pair. (1985)
  * Fix parameter duplication problem with PyStan (1962)
  * Temporarily disable pyjags tests (1963)
  * Fix tuple bug in coords (1695)
  * Fix extend 'right' join bug (1718)
  * Update attribute handling for InferenceData (1357)
  * Fix R2 implementation (1666)
  * Added warning message in plot_dist_comparison() in case subplots go over
    the limit (1688)
  * Fix coord value ignoring for default dims (2001)
  * Fixed plot_posterior with boolean data (1707)
  * Fix min_ess usage in plot_ess (2002)
  * Fixed typo in Forestplot documentation
  * Restructured contributing section and added several new pages to help
    contributing to docs (1903)
* Sat Mar  5 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.11.4:
  * Fix standard deviation code in density utils
* Thu Jan 14 2021 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
